function bnd=sph_bessel_diff(x,N)
% function bnd=sph_bessel_diff(x,N)
%
% evaluates all derivatives of the 
% spherical Bessel functions 
% (part of the regular solution)
% up to the degree N
% the definition was taken from:
%
% E. G. Williams, "Fourier Acoustics", 
% Academic Press, San Diego, 1999.
%
% this function depends on 
% sph_bessel_nearfield.m
% sph_bessel.m
%
% Franz Zotter (zotter@iem.at), 
% Institute of Electronic Music and Acoustics,
% 2007.
%

x=x(:);

ofs=1;
bn=sph_bessel(x,N+1);
bnd=zeros(length(x),N+1);

for n=0:N
   bnd(:,n+ofs)=n./x.*bn(:,n+ofs)-bn(:,n+1+ofs);
end
       
